{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "fb733b49",
   "metadata": {},
   "source": [
    "# Exercice 0\n",
    "\n",
    "Essayons d'éloigner GB du profil moyen, en faisant GB $\\simeq$ Italy."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "9b70f60d",
   "metadata": {},
   "outputs": [],
   "source": [
    "base_url = \"https://www.imo.universite-paris-saclay.fr/~auder/teachings/analyse-de-donnees/data\"\n",
    "data = read.csv(paste0(base_url,\"/table_Nobel.csv\"))\n",
    "# La première colonne contient les noms des pays = labels des lignes\n",
    "row.names(data) = data[,1]\n",
    "data = data[,-1]\n",
    "\n",
    "GBIndex = (1:nrow(data)) [row.names(data) == \"GB\"] #4\n",
    "ItalyIndex = (1:nrow(data)) [row.names(data) == \"Italie\"] #5\n",
    "data2 = data #R fera une copie quand on modifiera data2\n",
    "data2[GBIndex,] = data[ItalyIndex,] + rpois(ncol(data),3) - 3\n",
    "\n",
    "library(FactoMineR)\n",
    "res.ca = CA(data2, graph=FALSE)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "80a3ccca",
   "metadata": {},
   "outputs": [],
   "source": [
    "options(repr.plot.width=15, repr.plot.height=10)\n",
    "plot(res.ca)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3859cb28",
   "metadata": {},
   "source": [
    "Sans surprises, la Grande-Bretagne se retrouve du côté de l'Italie (fluctuations possibles dues à rpois). Le reste est à peu près inchangé.\n",
    "\n",
    "Ensuite, on peut vérifier l'affirmation comme quoi les résultats sont inchangés en fusionnant des lignes proportionnelles : fusionnons Italie et Grande-Bretagne après avoir tracé le graphe où ces deux lignes sont proportionnelles."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "e1413561",
   "metadata": {},
   "outputs": [],
   "source": [
    "data2[GBIndex,] = 2 * data[ItalyIndex,]\n",
    "res.ca_split = CA(data2, graph=FALSE)\n",
    "data2[ItalyIndex,] = 3 * data[ItalyIndex,]\n",
    "data2[GBIndex,] = data2[nrow(data),] #USA\n",
    "data2 = data2[-nrow(data),]\n",
    "row.names(data2)[GBIndex] = \"USA\"\n",
    "res.ca_fusion = CA(data2, graph=FALSE)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "21c13d96",
   "metadata": {},
   "outputs": [],
   "source": [
    "library(gridExtra)\n",
    "library(ggplot2)\n",
    "plot1 = plot(res.ca_split)\n",
    "plot2 = plot(res.ca_fusion)\n",
    "grid.arrange(plot1, plot2, ncol=2)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6157466b",
   "metadata": {},
   "source": [
    "Les graphes sont bien identiques."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9ef70620",
   "metadata": {},
   "source": [
    "# Exercice 1"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "a8304635",
   "metadata": {},
   "outputs": [],
   "source": [
    "data = read.csv(paste0(base_url,\"/MAMe_dataset.csv\"))\n",
    "head(data)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "95323fef",
   "metadata": {},
   "source": [
    "A priori, seules les colonnes Medium (type de toile) et Museum (nom du musée) sont qualitatives. Ceci dit, toute variable quantitative peut être considérée qualitative en la découpant en classes. Par exemple ici on pourrait considérer \"aspect ratio < 1 = portrait\" et \"aspect ratio > 1 = paysage\". On perdrait de l'information au passage donc il faudrait par exemple compléter par une ACP.\n",
    "\n",
    "On considère ici seulement Medium vs. Museum."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "f5a2f67e",
   "metadata": {},
   "outputs": [],
   "source": [
    "data_tbl = table(subset(data, select=c(\"Medium\",\"Museum\")))\n",
    "res.ca = CA(data_tbl, graph=FALSE)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "4c8dfcbd",
   "metadata": {},
   "outputs": [],
   "source": [
    "plot(res.ca)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2faa443f",
   "metadata": {},
   "source": [
    "Il semble y avoir (relativement) plus de Lithographs au musée de Cleveland, et plus de Hand-colored engravings à celui de LA. vérifions numériquement :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "31a219d6",
   "metadata": {},
   "outputs": [],
   "source": [
    "indices = row.names(data_tbl) %in% c(\"Lithograph\",\"Hand-colored engraving\")\n",
    "data_tbl[indices,]"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6b977539",
   "metadata": {},
   "source": [
    "Chose intéressante, la ligne Lithograph est plutôt du côté du musée de Cleveland, mais il y a autant de telles oeuvres au musée métropolitain. A priori expliqué par le fait que les types de tableaux du côté du musée métropolitain ont proportionnellement beaucoup plus d'oeuvres dans ce musée.\n",
    "\n",
    "En tout cas on n'y voit pas très clair..."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "67ab415c",
   "metadata": {},
   "outputs": [],
   "source": [
    "# Cherchons à regrouper les lignes similaires (résultat quasi inchangé, plus lisible)\n",
    "proportions = t(apply(data_tbl, 1, function(row) row / sum(row)))\n",
    "k = kmeans(proportions, 6) #6 trouvé par \"essais-erreurs\""
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "bd728256",
   "metadata": {},
   "outputs": [],
   "source": [
    "reduced_table = t(sapply(1:6, function(i) {\n",
    "    inds = (1:nrow(data_tbl))[k$cluster == i]\n",
    "    if (length(inds)>1) {colSums(data_tbl[inds,])} else {data_tbl[inds,]}\n",
    "}))\n",
    "row.names(reduced_table) = sapply(1:6, function(i) {\n",
    "    inds = (1:nrow(data_tbl))[k$cluster == i]\n",
    "    Reduce(function(x,y) paste(x, y, sep=\";\"), row.names(data_tbl)[inds])\n",
    "})"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "308c7f9e",
   "metadata": {},
   "outputs": [],
   "source": [
    "rbind(reduced_table, colMeans(reduced_table)) #profil moyen en bas"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "3306b28f",
   "metadata": {},
   "outputs": [],
   "source": [
    "res.ca = CA(reduced_table, graph=FALSE)\n",
    "plot(res.ca)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3157df95",
   "metadata": {},
   "source": [
    "Conformément aux résultats numériques, Albumen photograph;Clay;Hand-colored etching;Pen and brown ink;Silk and metal thread;Woven fabric + Faience;Glass;Ivory;Limestone;Steel;Wood + Graphite;Iron;Marble;Polychromed wood caractérisent plutôt le musée métropolitain. La variable regroupée Gold;Porcelain;Silver;Wood engraving;Woodcut  semblait aussi devoir être du côté du Metropolitan Museum, mais il y aussi beaucoup de telles toiles au Cleveland Museum, donc la variable n'a au final pas de direction précise. Enfin, Bronze;Ceramic;Engraving;Etching;Lithograph;Oil on canvas;Woodblock est plutôt à droite bien que ses proportions soient équilibrées (~33%). En effet le centre de gravité est biaisé vers le Metropolitan Museum."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d742257b",
   "metadata": {},
   "source": [
    "# Exercice 2"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "0996e666",
   "metadata": {},
   "outputs": [],
   "source": [
    "data = read.csv(paste0(base_url,\"/paintings.csv\"))\n",
    "head(data)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "35e4a0ee",
   "metadata": {},
   "source": [
    "La dernière colonne \"painting\" désigne la toile, et est a priori unique => identifiant. Vérifions :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "c7374755",
   "metadata": {},
   "outputs": [],
   "source": [
    "nrow(data) ; length(unique(data$painting))"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "bec39195",
   "metadata": {},
   "source": [
    "Les colonnes 1 à 48 contiennent les notes (de 1 à 5) attribuées par 48 étudiants à l'ensemble des 30 oeuvres. Une première idée consisterait à regarder les corrélations entre mouvement artistique et artiste. Ce n'est pas une super idée pour deux raisons :\n",
    " - un artiste peint a priori la plupart de ses toiles conformément à un unique mouvement ;\n",
    " - dans cette base chaque artiste n'est présent qu'une fois :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "66682530",
   "metadata": {},
   "outputs": [],
   "source": [
    "length(unique(data$artist))"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "26d67edd",
   "metadata": {},
   "source": [
    "Reste donc à étudier soit les corrélations inter-étudiants (why not), ou les affinités de chaque étudiant avec les mouvements artistiques. Comparons par exemple S4 à S23 puis S12 à art.movement."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "dd96b9e6",
   "metadata": {},
   "outputs": [],
   "source": [
    "t1 = table(subset(data, select=c(\"S4\",\"S23\")))\n",
    "res.ca = CA(t1, graph=FALSE)\n",
    "plot(res.ca)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "ec3065ee",
   "metadata": {},
   "source": [
    "Visuellement, on pourrait dire que quand l'un note 4 l'autre a tendance à noter 3, de même pour 3 / 5, 5 / 2 et 1 / 1 (attention l'ordre importe !). Numériquement c'est nettement plus flou :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "43bac0fb",
   "metadata": {},
   "outputs": [],
   "source": [
    "t1"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "f22d1e42",
   "metadata": {},
   "source": [
    "En effet hormis l'association assez ntette 1 / 1 (les deux ont tendance à détester les mêmes oeuvres), rien ne se détache vraiment surtout compte-tenu du faible nombre de lignes. On vérifie tout de même dans une certaine mesure 5 / 2 (seulement)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "381ed4a0",
   "metadata": {},
   "outputs": [],
   "source": [
    "t2 = table(subset(data, select=c(\"S12\",\"art.movement\")))\n",
    "res.ca = CA(t2, graph=FALSE)\n",
    "plot(res.ca)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "222f3264",
   "metadata": {},
   "source": [
    "Cet étudiant semble plutôt versé dans l'art nouveau et dans une moindre mesure l'impressionisme. Il apprécie assez Pop art/Romanticism/Post-Impressionism et a tendance à ne pas aimer le reste. Vérifions."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "62ace516",
   "metadata": {},
   "outputs": [],
   "source": [
    "t(t2)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "ac79e3f4",
   "metadata": {},
   "source": [
    "Pas évident de juger tout à l'oeil :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "ba73f637",
   "metadata": {},
   "outputs": [],
   "source": [
    "rowMeans(t2[,c(\"Art Nouveau\",\"Impressionism\")])\n",
    "rowMeans(t2[,c(\"Pop art\",\"Romanticism\",\"Post-Impressionism\")])\n",
    "rowMeans(t2[,c(\"Abstract art\",\"Baroque\",\"Cubism\",\"Nbeoclassicism\",\"Op art\",\"Renaissance\",\"Surrealism\",\"Symbolism\")])"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2965e24d",
   "metadata": {},
   "source": [
    "=> À peu près OK avec l'analyse."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "R",
   "language": "R",
   "name": "ir"
  },
  "language_info": {
   "codemirror_mode": "r",
   "file_extension": ".r",
   "mimetype": "text/x-r-source",
   "name": "R",
   "pygments_lexer": "r",
   "version": "4.1.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
